import type { Env, MinimalRequest, Session, User } from "../types.js";
import { Cookie, CookieOption } from "./cookie.js";
import { Adapter, SessionAdapter, UserAdapter, UserData } from "../types.js";
export { SESSION_COOKIE_NAME } from "./cookie.js";
export declare const lucia: <C extends Configurations>(configs: C) => Auth<C>;
export declare class Auth<C extends Configurations = any> {
    private adapter;
    private generateUserId;
    private sessionCookie;
    private sessionTimeout;
    private env;
    private hash;
    private autoDatabaseCleanup;
    private transformUserData;
    private csrfProtection;
    constructor(configs: C);
    getUser: (userId: string) => Promise<User>;
    getUserByProviderId: (provider: string, identifier: string) => Promise<User>;
    getSessionUser: (sessionId: string) => Promise<{
        user: User;
        session: Session;
    }>;
    createUser: (provider: string, identifier: string, options?: {
        password?: string;
        attributes?: Lucia.UserAttributes;
    }) => Promise<User>;
    updateUserAttributes: (userId: string, attributes: Partial<Lucia.UserAttributes>) => Promise<User>;
    updateUserProviderId: (userId: string, provider: string, identifier: string) => Promise<User>;
    updateUserPassword: (userId: string, password: string) => Promise<User>;
    deleteUser: (userId: string) => Promise<void>;
    authenticateUser: (provider: string, identifier: string, password: string) => Promise<User>;
    getSession: (sessionId: string) => Promise<Session>;
    validateSession: (sessionId: string) => Promise<Session>;
    validateSessionUser: (sessionId: string) => Promise<{
        session: Session;
        user: User;
    }>;
    generateSessionId: () => [sessionId: string, activePeriodExpires: Date, idlePeriodExpires: Date];
    createSession: (userId: string) => Promise<Session>;
    renewSession: (sessionId: string) => Promise<Session>;
    invalidateSession: (sessionId: string) => Promise<void>;
    invalidateAllUserSessions: (userId: string) => Promise<void>;
    deleteDeadUserSessions: (userId: string) => Promise<void>;
    validateRequestHeaders: (request: MinimalRequest) => string;
    createSessionCookies: (session: Session | null) => Cookie[];
}
type MaybePromise<T> = T | Promise<T>;
export interface Configurations {
    adapter: Adapter | {
        user: UserAdapter | Adapter;
        session: SessionAdapter | Adapter;
    };
    env: Env;
    generateCustomUserId?: () => Promise<string | null>;
    csrfProtection?: boolean;
    sessionTimeout?: {
        activePeriod: number;
        idlePeriod: number;
    };
    transformUserData?: (userData: UserData) => Record<string, any>;
    sessionCookie?: CookieOption[];
    hash?: {
        generate: (s: string) => MaybePromise<string>;
        validate: (s: string, hash: string) => MaybePromise<boolean>;
    };
    autoDatabaseCleanup?: boolean;
}
